package com.qmth.paper.library.common.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qmth.paper.library.common.contant.SystemConstant;
import com.qmth.paper.library.common.entity.SysSetting;
import com.qmth.paper.library.common.entity.SysUser;
import com.qmth.paper.library.common.enums.ExceptionResultEnum;
import com.qmth.paper.library.common.mapper.SysSettingMapper;
import com.qmth.paper.library.common.service.SysSettingService;
import com.qmth.paper.library.common.util.ServletUtil;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * <p>
 * 系统设置 服务实现类
 * </p>
 */
@Service
public class SysSettingServiceImpl extends ServiceImpl<SysSettingMapper, SysSetting> implements SysSettingService {

    @Override
    public SysSetting getData() {
        Long schoolId = Long.valueOf(ServletUtil.getRequestHeaderSchoolId().toString());
        QueryWrapper<SysSetting> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(SysSetting::getSchoolId, schoolId);
        List<SysSetting> sysSettingList = this.list(queryWrapper);
        if (!sysSettingList.isEmpty() && sysSettingList.size() > 1) {
            throw ExceptionResultEnum.ERROR.exception("系统设置有误，查出多条数据");
        }
        SysSetting sysSetting = new SysSetting();
        if (!sysSettingList.isEmpty()) {
            sysSetting = sysSettingList.get(0);
        }
        return sysSetting;
    }

    @Override
    public boolean saveData(SysSetting sysSetting) {
        Long schoolId = Long.valueOf(ServletUtil.getRequestHeaderSchoolId().toString());
        Long userId = Long.valueOf(ServletUtil.getRequestHeaderUserId().toString());

        QueryWrapper<SysSetting> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(SysSetting::getSchoolId, schoolId);
        SysSetting oldSysSetting = this.getOne(queryWrapper);

        // 新增
        if (oldSysSetting == null) {
            sysSetting.setId(SystemConstant.getDbUuid());
            sysSetting.setSchoolId(schoolId);
            sysSetting.setCreateId(userId);
            sysSetting.setCreateTime(System.currentTimeMillis());
            return this.save(sysSetting);
        } else {
             if (!oldSysSetting.getSchoolId().equals(schoolId)) {
                throw ExceptionResultEnum.ERROR.exception("查询数据学校与当前学校不一致");
            }
            oldSysSetting.setOpenOcr(sysSetting.getOpenOcr());
            oldSysSetting.setOpenGlobalMatch(sysSetting.getOpenGlobalMatch());
            oldSysSetting.setUpdateId(userId);
            oldSysSetting.setUpdateTime(System.currentTimeMillis());
            return this.updateById(oldSysSetting);
        }
    }
}
